﻿using System;
using System.ComponentModel;
using System.IO;
using System.Windows.Forms;
using Bunifu.Utils;
using CefSharp;
using CefSharp.WinForms;
using EasyTabs;
using XeroBrowser.Properties;
// ReSharper disable PossibleNullReferenceException

namespace XeroBrowser
{
    public partial class FrmBrowser : Form
    {   
        Uri _fileUri;
        Uri _fileUri2;
        public FrmBrowser()
        {
            InitializeComponent();
            chromiumWebBrowser1.DownloadHandler = new DownloadHandler(this);
            chromiumWebBrowser1.LifeSpanHandler = new LifeSpanHandler();
            chromiumWebBrowser1.MenuHandler = new MenuHandler();
            chromiumWebBrowser1.DisplayHandler = new DisplayHandler(this);

            string filePath = Path.Combine(AppDomain.CurrentDomain.BaseDirectory, "index.html");
            _fileUri = new Uri(filePath);
            string fileUrl = _fileUri.AbsoluteUri;

            string filePath2 = Path.Combine(AppDomain.CurrentDomain.BaseDirectory, "loaderror.html");
            _fileUri2 = new Uri(filePath2);
            string fileUrl2 = _fileUri2.AbsoluteUri;

            chromiumWebBrowser1.Load(fileUrl);
            txtSearchOrUrl.Text = "";
            CheckForIllegalCrossThreadCalls = false;
        }


        public TitleBarTabs ParentTabs => (ParentForm as TitleBarTabs);

        private void btnForward_Click(object sender, EventArgs e)
        {
            if (chromiumWebBrowser1.CanGoForward) chromiumWebBrowser1.Forward();

        }

        public void ChangeUrl(string url)
        {
            chromiumWebBrowser1.Load(url);
        }

        private void btnBack_Click(object sender, EventArgs e)
        {
            if (chromiumWebBrowser1.CanGoBack) chromiumWebBrowser1.Back();

        }

        private void btnRefresh_Click(object sender, EventArgs e)
        {
            chromiumWebBrowser1.Reload();
        }

        private bool _isBlocked;
        private void chromiumWebBrowser1_LoadingStateChanged(object sender, LoadingStateChangedEventArgs e)
        {
            if (e.IsLoading)
            {
                loadingIndicator.Visible = true;
                btnRefresh.Visible = false;
            }
            else
            {
                loadingIndicator.Visible = false;
                btnRefresh.Visible = true;
            }

            try
            {
                Invoke((Action)delegate
                {
                    if (txtSearchOrUrl != null && chromiumWebBrowser1 != null)
                    {
                        txtSearchOrUrl.Text = !chromiumWebBrowser1.Address.EndsWith(_fileUri.ToString()) && !chromiumWebBrowser1.Address.EndsWith(_fileUri2.ToString()) ? chromiumWebBrowser1.Address : "";
                    }
                });

            }
            catch (ObjectDisposedException) { }
            catch (InvalidAsynchronousStateException) { }

            var uri = new Uri(chromiumWebBrowser1.Address);
            if (uri.Scheme == "file")
            {
                txtSearchOrUrl.IconLeft = Resources.local;

            }
            else if (uri.Scheme == "https")
            {
                txtSearchOrUrl.IconLeft = Resources.secure;
            }
            else
            {
                txtSearchOrUrl.IconLeft = Resources.insecure1;
                if (!_isBlocked)
                {
                    MessageBox.Show(@"Warning: This site is insecure!, Your personal information may be at risk or hackers can install malicious software on your device.", @"Xero Browser", MessageBoxButtons.OK, MessageBoxIcon.Warning);
                }
            }


            // if (txtSearchOrUrl.Text.Contains("netflix.com"))
            //  {
            //MessageBox.Show("This site requires a DRM (Digital Rights Management) which Xero Browser does not support! TV Shows & Moves will not load.", "Xero Browser", System.Windows.Forms.MessageBoxButtons.OK, System.Windows.Forms.MessageBoxIcon.Warning);
            //     chromiumWebBrowser1.Stop(); // cancel the navigation
            //     isBlocked = true;
            //     chromiumWebBrowser1.LoadHtml("<html><body><h1>Error!</h1><h3>This site requires a DRM (Digital Rights Management) which Xero Browser does not support! TV Shows & Moves will not load.</h3></body></html>");
            //   }
            //  else if (txtSearchOrUrl.Text.Contains("disneyplus.com"))
            //  {
            //      MessageBox.Show("This site requires a DRM (Digital Rights Management) which Xero Browser does not support! TV Shows & Moves will not load.", "Xero Browser", System.Windows.Forms.MessageBoxButtons.OK, System.Windows.Forms.MessageBoxIcon.Warning);
            //  }

            if (e.IsLoading)
            {
                // Don't return, allow the code to execute the rest of the logic
            }

            string[] blockedUrls = { "https://diamondcreeper.org/1337", "https://www.youtube.com/watch?v=dQw4w9WgXcQ", "https://www.youtube.com/watch?v=xm3YgoEiEDc", "https://www.youtube.com/watch?v=xvFZjo5PgG0", "https://www.youtube.com/watch?v=O91DT1pR1ew", "https://www.youtube.com/watch?v=o-YBDTqX_ZU", "https://www.youtube.com/watch?v=H8ZH_mkfPUY", "https://www.youtube.com/watch?v=o-YBDTqX_ZU", "https://www.youtube.com/watch?v=xvFZjo5PgG0" };
            string[] blockedDrms = { "https://www.netflix.com/", "https://www.disneyplus.com/", "https://www.twitch.tv/" };

            if (!_isBlocked)
            {
                foreach (string blockedDrm in blockedDrms)
                {
                    if (chromiumWebBrowser1.Address.StartsWith(blockedDrm))
                    {
                        chromiumWebBrowser1.Stop(); // cancel the navigation
                        _isBlocked = true;
                        chromiumWebBrowser1.LoadHtml("<html><body><h1>Error!</h1><h3>This website requires a DRM (Digital Rights Management) which Xero Browser does not support!</h3></body></html>", blockedDrm);
                    }

                }

                foreach (string blockedUrl in blockedUrls)
                {
                    if (chromiumWebBrowser1.Address.StartsWith(blockedUrl))
                    {
                        chromiumWebBrowser1.Stop(); // cancel the navigation
                        _isBlocked = true;
                        chromiumWebBrowser1.LoadHtml("<html><body><h1>Rickroll Blocked!</h1><p>Being rickrolled is disabled.</p></body></html>", blockedUrl);
                    }

                }
            }
        }

        private void chromiumWebBrowser1_TitleChanged(object sender, TitleChangedEventArgs e)
        {
            try
            {
                Invoke((Action)delegate { FindForm().Text = e.Title; });
            }
            catch (ObjectDisposedException) { }
        }

        private void btnSettings_Click(object sender, EventArgs e)
        {
            Backdrop.Show(new FrmSettings());
        }

        private void chromiumWebBrowser1_KeyDown(object sender, KeyEventArgs e)
        {
        }

        private void bunifuImageButton1_Click(object sender, EventArgs e)
        {
            chromiumWebBrowser1.ShowDevTools();
            
        }

        private void chromiumWebBrowser1_LoadError(object sender, LoadErrorEventArgs e)
        {
           // string filePath = Path.Combine(AppDomain.CurrentDomain.BaseDirectory, "loaderror.html");
           // _fileUri2 = new Uri(filePath);
           // string fileUrl = _fileUri2.AbsoluteUri;
           // chromiumWebBrowser1.Load(fileUrl);
        }

        private void txtSearchOrUrl_KeyUp(object sender, KeyEventArgs e)
        {
            if (e.KeyCode == Keys.Enter && txtSearchOrUrl.Text.Trim().Length > 0)
            {
                if (txtSearchOrUrl.Text.Contains("."))
                {
                    chromiumWebBrowser1.Load(txtSearchOrUrl.Text.Trim());
                }
                else
                {
                    chromiumWebBrowser1.Load("https://www.google.com/search?q=" + txtSearchOrUrl.Text.Trim().Replace(" ", "+") + "&sourceid=chrome&ie=UTF-8");
                }
            }
        }

        private void txtSearchOrUrl_KeyDown(object sender, KeyEventArgs e)
        {
            if (e.KeyCode == Keys.Enter)
            {

                e.Handled = true;
                e.SuppressKeyPress = true;

            }
        }

        private void bunifuImageButton3_Click(object sender, EventArgs e)
        {

        }

        private void bunifuImageButton2_Click(object sender, EventArgs e)
        {
            chromiumWebBrowser1.Load("https://google.com");
        }
    }

}
